## Version 0.2.3

This release includes several enhancements to the ChatBot and QueryBot functionalities, as well as improvements to testing and streaming capabilities.

### New Features

- Bump version to 0.2.3 (d61ee4c) (github-actions)
- Enhance ChatBot functionality and testing: Add `stream_target` parameter, update test cases, remove deprecated methods, and introduce new tests (17428e8) (Eric Ma)
- Add unit test for QueryBot initialization using Hypothesis for property-based testing (2aa9461) (Eric Ma)
- Streamline stdout streaming in QueryBot and remove unnecessary constructor parameter (2f39593) (Eric Ma)
- Enhance SimpleBot tests with stream API scenarios (0ea04b8) (Eric Ma)
- Remove redundant test_chatbot_call and update test_chatbot_repr (3ec0aa8) (Eric Ma)
- Simplify mocking in chatbot repr test (244dad9) (Eric Ma)
- Remove debug print statement and streamline commit message echo in SimpleBot (f16d7a3) (Eric Ma)
- Correct dictionary access and message concatenation in SimpleBot (79d2929) (Eric Ma)
- Allow passing additional kwargs to completion function in ChatBot (4058693) (Eric Ma)
- Enhance streaming capabilities and add type hints in ChatBot (c11aace) (Eric Ma)
- Remove deprecated Jupyter notebook example for streaming (d6693a3) (Eric Ma)
- Replace 'stream' parameter with 'stream_target' for more flexible output options (1211115) (Eric Ma)
- Enhance SimpleBot streaming capabilities and update notebook examples (ab8c359) (Eric Ma)

### Bug Fixes

- Fix ChatBot response mocking in unit test (7c02d18) (Eric Ma)
- Correct dictionary access and message concatenation in SimpleBot (79d2929) (Eric Ma)
- Replace pdfminer with pdfminer.six for better Python 3 support (79908b1) (Eric Ma)
- Replace pdfreader with pdfminer for improved PDF processing (7910e3e) (Eric Ma)

### Deprecations

- Remove 'api' stream\_target from ChatBot and change the expected return type for consumers of the ChatBot class (c11aace) (Eric Ma)
- Replace 'stream' boolean parameter with 'stream\_target' in ChatBot and SimpleBot constructors (1211115) (Eric Ma)

Please note that some breaking changes have been introduced in this release. Make sure to update your code accordingly. For more details, refer to the individual commit messages.
